@@ -1,6 +1,6 @@
 """PyUSB virtual FTDI device."""
 
-# Copyright (c) 2020-2021, Emmanuel Blot <emmanuel.blot@free.fr>
+# Copyright (c) 2020-2023, Emmanuel Blot <emmanuel.blot@free.fr>
 # All rights reserved.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -230,14 +230,15 @@ class VirtFtdiPort:
         SYNCFF = 0x40   # Single Channel Synchronous FIFO mode
 
     FIFO_SIZES = {
-        0x0200: (128, 128),    # FT232AM: TX: 128, RX: 128
-        0x0400: (128, 384),    # FT232BM: TX: 128, RX: 384
-        0x0500: (128, 384),    # FT2232C: TX: 128, RX: 384
-        0x0600: (256, 128),    # FT232R:  TX: 256, RX: 128
-        0x0700: (4096, 4096),  # FT2232H: TX: 4KiB, RX: 4KiB
-        0x0800: (2048, 2048),  # FT4232H: TX: 2KiB, RX: 2KiB
-        0x0900: (1024, 1024),  # FT232H:  TX: 1KiB, RX: 1KiB
-        0x1000: (512, 512),    # FT-X:    TX: 512, RX: 512
+        0x0200: (128, 128),    # FT232AM:   TX: 128, RX: 128
+        0x0400: (128, 384),    # FT232BM:   TX: 128, RX: 384
+        0x0500: (128, 384),    # FT2232C:   TX: 128, RX: 384
+        0x0600: (256, 128),    # FT232R:    TX: 256, RX: 128
+        0x0700: (4096, 4096),  # FT2232H:   TX: 4KiB, RX: 4KiB
+        0x0800: (2048, 2048),  # FT4232H:   TX: 2KiB, RX: 2KiB
+        0x0900: (1024, 1024),  # FT232H:    TX: 1KiB, RX: 1KiB
+        0x1000: (512, 512),    # FT-X:      TX: 512, RX: 512
+        0x3600: (2048, 2048),  # FT4232HA:  TX: 2KiB, RX: 2KiB
     }
     """FTDI chip internal FIFO sizes.
 
@@ -252,7 +253,8 @@ class VirtFtdiPort:
         0x0700: 16,
         0x0800: 8,
         0x0900: 16,
-        0x1000: 8}
+        0x1000: 8,
+        0x3600: 8}
     """Interterface pin count."""
 
     UART_PINS = IntEnum('UartPins', 'TXD RXD RTS CTS DTR DSR DCD RI', start=0)
@@ -972,6 +974,7 @@ class VirtFtdi:
         0x0800: Properties(4, 8, 0),   # FT4232H
         0x0900: Properties(1, 8, 10),  # FT232H
         0x1000: Properties(1, 8, 4),   # FT231X
+        0x3600: Properties(4, 8, 0),   # FT4232HA
     }
     """Width of port/bus (regular, cbus)."""
 
